@@ -31,12 +31,14 @@ CONCATENATOR_DATA_FILES = (
 )
 
 DEFAULT_RESOURCE_DIR = os.path.join(os.getcwd(), "data")
-SUPPORTED_ANALYZERS = (
+SUPPORTED_ANALYZERS =  (
     "lemmas",
     "pos_tags",
     "transliteration",
     "ner",
-    "contacts",
+    "addresses",
+    "emails",
+    "phone_strict",
     "entities",
     "namemail",
     "bounded"
